summaryrefslogtreecommitdiff
path: root/src/cmd/go/list.go
diff options
context:
space:
mode:
authorSanjay Menakuru <balasanjay@gmail.com>2012-01-03 14:12:54 +1100
committerSanjay Menakuru <balasanjay@gmail.com>2012-01-03 14:12:54 +1100
commit7fa9fdacb85f5e465494d6ac3f6946f4a0f42202 (patch)
tree71191966dac7c39813e8434f1e3a09de512c36aa /src/cmd/go/list.go
parent0233a448444b312489cfd3bb70658bc12a6020fa (diff)
downloadgo-7fa9fdacb85f5e465494d6ac3f6946f4a0f42202.tar.gz
cmd/go: include test files in the files sent to gofmt, govet, and gofix
Also, add TestGoFiles to the go command's public api. R=golang-dev, adg CC=golang-dev http://codereview.appspot.com/5505083 Committer: Andrew Gerrand <adg@golang.org>
Diffstat (limited to 'src/cmd/go/list.go')
-rw-r--r--src/cmd/go/list.go11
1 files changed, 6 insertions, 5 deletions
diff --git a/src/cmd/go/list.go b/src/cmd/go/list.go
index 21ebb5e20..9a1a4ecb1 100644
--- a/src/cmd/go/list.go
+++ b/src/cmd/go/list.go
@@ -36,11 +36,12 @@ being passed to the template is:
Stale bool // would 'go install' do anything for this package?
// Source files
- GoFiles []string // .go source files (excluding CgoFiles)
- CFiles []string // .c source files
- HFiles []string // .h source files
- SFiles []string // .s source files
- CgoFiles []string // .go sources files that import "C"
+ GoFiles []string // .go source files (excluding CgoFiles and TestGoFiles)
+ TestGoFiles []string // _test.go source files
+ CFiles []string // .c source files
+ HFiles []string // .h source files
+ SFiles []string // .s source files
+ CgoFiles []string // .go sources files that import "C"
// Dependency information
Imports []string // import paths used by this package